"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useConnectionByState = exports.useConnectionById = exports.useConnections = void 0;
const core_1 = require("@aries-framework/core");
const React = __importStar(require("react"));
const react_1 = require("react");
const ConnectionContext = (0, react_1.createContext)(undefined);
const useConnections = () => {
    const connectionContext = (0, react_1.useContext)(ConnectionContext);
    if (!connectionContext) {
        throw new Error('useConnections must be used within a ConnectionContextProvider');
    }
    return connectionContext;
};
exports.useConnections = useConnections;
const useConnectionById = (id) => {
    const { connections } = (0, exports.useConnections)();
    return connections.find((c) => c.id === id);
};
exports.useConnectionById = useConnectionById;
const useConnectionByState = (state) => {
    const { connections } = (0, exports.useConnections)();
    const filteredConnections = (0, react_1.useMemo)(() => connections.filter((c) => c.state === state), [connections, state]);
    return filteredConnections;
};
exports.useConnectionByState = useConnectionByState;
const ConnectionProvider = ({ agent, children }) => {
    const [connectionState, setConnectionState] = (0, react_1.useState)({
        connections: [],
        loading: true,
    });
    const setInitialState = async () => {
        if (agent) {
            const connections = await agent.connections.getAll();
            setConnectionState({ connections, loading: false });
        }
    };
    (0, react_1.useEffect)(() => {
        setInitialState();
    }, [agent]);
    (0, react_1.useEffect)(() => {
        if (!connectionState.loading) {
            const listener = (event) => {
                const newConnectionsState = [...connectionState.connections];
                const index = newConnectionsState.findIndex((connection) => connection.id === event.payload.connectionRecord.id);
                if (index > -1) {
                    newConnectionsState[index] = event.payload.connectionRecord;
                }
                else {
                    newConnectionsState.unshift(event.payload.connectionRecord);
                }
                setConnectionState({
                    loading: connectionState.loading,
                    connections: newConnectionsState,
                });
            };
            agent === null || agent === void 0 ? void 0 : agent.events.on(core_1.ConnectionEventTypes.ConnectionStateChanged, listener);
            return () => {
                agent === null || agent === void 0 ? void 0 : agent.events.off(core_1.ConnectionEventTypes.ConnectionStateChanged, listener);
            };
        }
    }, [connectionState, agent]);
    return React.createElement(ConnectionContext.Provider, { value: connectionState }, children);
};
exports.default = ConnectionProvider;
//# sourceMappingURL=ConnectionProvider.js.map